@@ -1,5 +1,5 @@
 /* 
-   Copyright (C) 2009, 2010, 2011 German A. Arias <german@xelalug.org>
+   Copyright (C) 2009, 2010, 2011, 2012 German A. Arias <german@xelalug.org>
 
    This file is part of FísicaLab application
 
@@ -876,6 +876,14 @@
   return YES;
 }
 
+- (void) tableView: (NSTableView*)aTableView 
+   willDisplayCell: (id)aCell 
+    forTableColumn: (NSTableColumn*)aTableColumn 
+	       row: (int)rowIndex
+{
+  [aCell setEditable: YES];
+}
+
 - (void) dealloc
 {
   RELEASE(listaObjetos) ;
